@@ -1,11 +1,28 @@
-import os
 import re
 
 from django.conf.urls.defaults import *
+from django.views.defaults import page_not_found
 
 from sentry.conf.settings import KEY
 from sentry.web import views, feeds
 
+handler404 = lambda x: page_not_found(x, template_name='sentry/404.html')
+
+def handler500(request):
+    """
+    500 error handler.
+
+    Templates: `500.html`
+    Context: None
+    """
+    from django.template import Context, loader
+    from django.http import HttpResponseServerError
+    
+    context = {'request': request}
+    
+    t = loader.get_template('sentry/500.html')
+    return HttpResponseServerError(t.render(Context(context)))
+
 urlpatterns = patterns('',
     url(r'^_static/(?P<path>.*)$', views.static_media, name='sentry-media'),
 
