@@ -18,12 +18,12 @@ from django.utils.safestring import mark_safe
 from django.views.decorators.csrf import csrf_protect, csrf_exempt
 
 from sentry.conf import settings
-from sentry.utils import get_filters, is_float, get_signature, parse_auth_header
-from sentry.utils.compat import pickle
 from sentry.models import GroupedMessage, Message
 from sentry.plugins import GroupActionProvider
 from sentry.templatetags.sentry_helpers import with_priority
-from sentry.utils import json
+from sentry.utils import get_filters, is_float, get_signature, parse_auth_header, json
+from sentry.utils.compat import pickle
+from sentry.utils.charts import has_charts
 from sentry.web.reporter import ImprovedExceptionReporter
 
 uuid_re = re.compile(r'^[a-z0-9]{32}$')
@@ -282,8 +282,23 @@ def ajax_handler(request):
         response = HttpResponse(json.dumps(data))
         response['Content-Type'] = 'application/json'
         return response
-        
-    if op in ['notification','poll','resolve', 'clear']:
+    
+    def chart(request):
+        gid = request.REQUEST.get('gid')
+        if not gid:
+            return HttpResponseForbidden()
+
+        try:
+            group = GroupedMessage.objects.get(pk=gid)
+        except GroupedMessage.DoesNotExist:
+            return HttpResponseForbidden()
+        data = GroupedMessage.objects.get_chart_data(group)
+
+        response = HttpResponse(json.dumps(data))
+        response['Content-Type'] = 'application/json'
+        return response
+    
+    if op in ['notification','poll','resolve', 'clear','chart']:
         return locals()[op](request)  
     else:
         return HttpResponseBadRequest()
